@@ -15,9 +15,15 @@ class AlignedWindow(gtk.Window):
         ourWidth  = (self.window.get_geometry())[2]
         ourHeight = (self.window.get_geometry())[3]
 
+	# Skip the taskbar, and the pager, stick and stay on top
+	self.stick()
+	# not wrapped self.set_skip_taskbar_hint(gtk.TRUE)
+	# not wrapped self.set_skip_pager_hint(gtk.TRUE)
+	self.set_type_hint (gtk.gdk.WINDOW_TYPE_HINT_DOCK)
+
         # Get the dimensions/position of the widgetToAlignWith
         self.widgetToAlignWith.realize()
-        (entryX, entryY) = self.widgetToAlignWith.window.get_origin()
+	entryX, entryY = self.widgetToAlignWith.window.get_origin()
         entryWidth  = (self.widgetToAlignWith.window.get_geometry())[2]
         entryHeight = (self.widgetToAlignWith.window.get_geometry())[3]
 
